==> lyx-2.0.4.tar.xz: lyx-2.0.4/src/lyxmathed.cpp <==

#include "mathed/InsetMathAMSArray.cpp" 
#include "mathed/InsetMathArray.cpp" 
#include "mathed/InsetMathBig.cpp" 
#include "mathed/InsetMathBoldSymbol.cpp" 
#include "mathed/InsetMathBox.cpp" 
#include "mathed/InsetMathBrace.cpp" 
#include "mathed/InsetMath.cpp" 
#include "mathed/InsetMathCases.cpp" 
#include "mathed/InsetMathChar.cpp" 
#include "mathed/InsetMathColor.cpp" 
#include "mathed/CommandInset.cpp" 
#include "mathed/InsetMathComment.cpp" 
#include "mathed/InsetMathDecoration.cpp" 
#include "mathed/InsetMathDecoration.h" 
#include "mathed/InsetMathDelim.cpp" 
#include "mathed/InsetMathDiff.cpp" 
#include "mathed/InsetMathDots.cpp" 
#include "mathed/InsetMathEnsureMath.cpp" 
#include "mathed/InsetMathEnv.cpp" 
#include "mathed/InsetMathExFunc.cpp" 
#include "mathed/InsetMathExInt.cpp" 
#include "mathed/InsetMathFont.cpp" 
#include "mathed/InsetMathFontOld.cpp" 
#include "mathed/InsetMathFrac.cpp" 
#include "mathed/InsetMathGrid.cpp" 
#include "mathed/InsetMathHull.cpp" 
#include "mathed/InsetMathKern.cpp" 
#include "mathed/InsetMathLefteqn.cpp" 
#include "mathed/InsetMathLim.cpp" 
#include "mathed/MathMacro.cpp" 
#include "mathed/InsetMathMatrix.cpp" 
#include "mathed/InsetMathNest.cpp" 
#include "mathed/InsetMathNumber.cpp" 
#include "mathed/InsetMathOverset.cpp" 
#include "mathed/InsetMathPar.cpp" 
#include "mathed/InsetMathPhantom.cpp" 
#include "mathed/InsetMathRef.cpp" 
#include "mathed/InsetMathRoot.cpp" 
#include "mathed/InsetMathScript.cpp" 
#include "mathed/InsetMathSize.cpp" 
#include "mathed/InsetMathSpace.cpp" 
#include "mathed/InsetMathSpecialChar.cpp" 
#include "mathed/InsetMathSplit.cpp" 
#include "mathed/InsetMathSqrt.cpp" 
#include "mathed/InsetMathStackrel.cpp" 
#include "mathed/InsetMathString.cpp" 
#include "mathed/InsetMathSubstack.cpp" 
#include "mathed/InsetMathSymbol.cpp" 
#include "mathed/InsetMathTabular.cpp" 
#include "mathed/InsetMathUnderset.cpp" 
#include "mathed/InsetMathUnknown.cpp" 
#include "mathed/InsetMathXArrow.cpp" 
#include "mathed/InsetMathXYMatrix.cpp" 
#include "mathed/InsetMathDiagram.cpp" 
#include "mathed/MathAtom.cpp" 
#include "mathed/MathAutoCorrect.cpp" 
#include "mathed/MathData.cpp" 
#include "mathed/MathExtern.cpp" 
#include "mathed/MathFactory.cpp" 
#include "mathed/MathMacroArgument.cpp" 
#include "mathed/MacroTable.cpp" 
#include "mathed/MathMacroTemplate.cpp" 
#include "mathed/MathParser.cpp" 
#include "mathed/MathStream.cpp" 
#include "mathed/MathSupport.cpp" 
#include "mathed/TextPainter.cpp"

==> lyx-2.1.2.tar.xz: lyx-2.1.2/src/lyxmathed.cpp <==

#include "mathed/CommandInset.cpp" 
#include "mathed/InsetMathAMSArray.cpp" 
#include "mathed/InsetMathArray.cpp" 
#include "mathed/InsetMathBig.cpp" 
#include "mathed/InsetMathBoldSymbol.cpp" 
#include "mathed/InsetMathBox.cpp" 
#include "mathed/InsetMathBrace.cpp" 
#include "mathed/InsetMath.cpp" 
#include "mathed/InsetMathCases.cpp" 
#include "mathed/InsetMathChar.cpp" 
#include "mathed/InsetMathColor.cpp" 
#include "mathed/InsetMathComment.cpp" 
#include "mathed/InsetMathDecoration.cpp" 
#include "mathed/InsetMathDecoration.h" 
#include "mathed/InsetMathDelim.cpp" 
#include "mathed/InsetMathDiff.cpp" 
#include "mathed/InsetMathDots.cpp" 
#include "mathed/InsetMathEnsureMath.cpp" 
#include "mathed/InsetMathEnv.cpp" 
#include "mathed/InsetMathExFunc.cpp" 
#include "mathed/InsetMathExInt.cpp" 
#include "mathed/InsetMathFont.cpp" 
#include "mathed/InsetMathFontOld.cpp" 
#include "mathed/InsetMathFrac.cpp" 
#include "mathed/InsetMathGrid.cpp" 
#include "mathed/InsetMathHull.cpp" 
#include "mathed/InsetMathKern.cpp" 
#include "mathed/InsetMathLefteqn.cpp" 
#include "mathed/InsetMathLim.cpp" 
#include "mathed/InsetMathCancel.cpp" 
#include "mathed/InsetMathCancelto.cpp" 
#include "mathed/InsetMathMatrix.cpp" 
#include "mathed/InsetMathNest.cpp" 
#include "mathed/InsetMathNumber.cpp" 
#include "mathed/InsetMathOverset.cpp" 
#include "mathed/InsetMathPar.cpp" 
#include "mathed/InsetMathPhantom.cpp" 
#include "mathed/InsetMathRef.cpp" 
#include "mathed/InsetMathRoot.cpp" 
#include "mathed/InsetMathScript.cpp" 
#include "mathed/InsetMathSideset.cpp" 
#include "mathed/InsetMathSize.cpp" 
#include "mathed/InsetMathSpace.cpp" 
#include "mathed/InsetMathSpecialChar.cpp" 
#include "mathed/InsetMathSplit.cpp" 
#include "mathed/InsetMathSqrt.cpp" 
#include "mathed/InsetMathStackrel.cpp" 
#include "mathed/InsetMathString.cpp" 
#include "mathed/InsetMathSubstack.cpp" 
#include "mathed/InsetMathSymbol.cpp" 
#include "mathed/InsetMathTabular.cpp" 
#include "mathed/InsetMathUnderset.cpp" 
#include "mathed/InsetMathUnknown.cpp" 
#include "mathed/InsetMathXArrow.cpp" 
#include "mathed/InsetMathXYMatrix.cpp" 
#include "mathed/InsetMathDiagram.cpp" 
#include "mathed/MathAtom.cpp" 
#include "mathed/MathAutoCorrect.cpp" 
#include "mathed/MathData.cpp" 
#include "mathed/MathExtern.cpp" 
#include "mathed/MathFactory.cpp" 
#include "mathed/MathMacro.cpp" 
#include "mathed/MathMacroArgument.cpp" 
#include "mathed/MacroTable.cpp" 
#include "mathed/MathMacroTemplate.cpp" 
#include "mathed/MathParser.cpp" 
#include "mathed/MathStream.cpp" 
#include "mathed/MathSupport.cpp" 
#include "mathed/TextPainter.cpp"
